APIs code
=========

.. the-cli-api-ref

Command Specifications
----------------------

user
^^^^

.. automodule:: kamaki.cli.commands.astakos
    :members:
    :undoc-members:

cyclades (server, flavor, network)
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: kamaki.cli.commands.cyclades
    :members:
    :undoc-members:

pithos (file)
^^^^^^^^^^^^^

.. automodule:: kamaki.cli.commands.pithos
    :members:
    :undoc-members:

image
^^^^^

.. automodule:: kamaki.cli.commands.image
    :members:
    :undoc-members:

Kamaki commands
^^^^^^^^^^^^^^^

config
""""""

.. automodule:: kamaki.cli.commands.config
    :members:
    :undoc-members:

history
"""""""

.. automodule:: kamaki.cli.commands.history
    :members:
    :undoc-members:

Command Line Interfaces
-----------------------

argument
^^^^^^^^

.. automodule:: kamaki.cli.argument
    :members:
    :show-inheritance:
    :undoc-members:


command_shell
^^^^^^^^^^^^^

.. automodule:: kamaki.cli.command_shell
    :members:
    :show-inheritance:
    :undoc-members:


command_tree
^^^^^^^^^^^^

.. automodule:: kamaki.cli.command_tree
    :members:
    :show-inheritance:
    :undoc-members:


config
^^^^^^

.. automodule:: kamaki.cli.config
    :members:
    :show-inheritance:
    :undoc-members:

errors
^^^^^^

.. automodule:: kamaki.cli.errors
    :members:
    :show-inheritance:
    :undoc-members:


history
^^^^^^^

.. automodule:: kamaki.cli.history
    :members:
    :show-inheritance:
    :undoc-members:


utils
^^^^^

.. automodule:: kamaki.cli.utils
    :members:
    :show-inheritance:
    :undoc-members:


.. _the-client-api-ref:

The clients API
---------------

Modules list
^^^^^^^^^^^^

compute REST API
^^^^^^^^^^^^^^^^

.. automodule:: kamaki.clients.compute.rest_api
    :members:
    :show-inheritance:
    :undoc-members:


compute
^^^^^^^

.. automodule:: kamaki.clients.compute
    :members:
    :show-inheritance:
    :undoc-members:


cyclades REST API
^^^^^^^^^^^^^^^^^

.. automodule:: kamaki.clients.cyclades.rest_api
    :members:
    :show-inheritance:
    :undoc-members:

cyclades
^^^^^^^^

.. automodule:: kamaki.clients.cyclades
    :members:
    :show-inheritance:
    :undoc-members:


storage
^^^^^^^

.. automodule:: kamaki.clients.storage
    :members:
    :show-inheritance:
    :undoc-members:

pithos_rest_api
^^^^^^^^^^^^^^^

.. automodule:: kamaki.clients.pithos.rest_api
    :members:
    :show-inheritance:
    :undoc-members:

pithos
^^^^^^

.. automodule:: kamaki.clients.pithos
    :members:
    :show-inheritance:
    :undoc-members:

image
^^^^^

.. automodule:: kamaki.clients.image
    :members:
    :show-inheritance:
    :undoc-members:


astakos
^^^^^^^

.. automodule:: kamaki.clients.astakos
    :members:
    :show-inheritance:
    :undoc-members:


utils
^^^^^

.. automodule:: kamaki.clients.utils
    :members:
    :show-inheritance:
    :undoc-members:
